/*
 * $Id: RenameFileCommand.java 2458 2009-09-29 10:56:38Z magicduncan $
 * $URL: https://open.jira.com/svn/IKASAN/tags/ikasan-0.8.3/connector-basefiletransfer/src/main/java/org/ikasan/connector/basefiletransfer/outbound/command/RenameFileCommand.java $
 * 
 * ====================================================================
 * Ikasan Enterprise Integration Platform
 * 
 * Distributed under the Modified BSD License.
 * Copyright notice: The copyright for this software and a full listing 
 * of individual contributors are as shown in the packaged copyright.txt 
 * file. 
 * 
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 *
 *  - Redistributions of source code must retain the above copyright notice, 
 *    this list of conditions and the following disclaimer.
 *
 *  - Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation 
 *    and/or other materials provided with the distribution.
 *
 *  - Neither the name of the ORGANIZATION nor the names of its contributors may
 *    be used to endorse or promote products derived from this software without 
 *    specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE 
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE 
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL 
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR 
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE 
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * ====================================================================
 */
package org.ikasan.connector.basefiletransfer.outbound.command;

import javax.resource.ResourceException;

import org.apache.log4j.Logger;
import org.ikasan.connector.base.command.ExecutionContext;
import org.ikasan.connector.base.command.ExecutionOutput;

/**
 * Renames files from a remote browsable directory
 * 
 * @author Ikasan Development Team
 */
public class RenameFileCommand extends AbstractBaseFileTransferTransactionalResourceCommand
{
    /** The logger instance. */
    private static Logger logger = Logger.getLogger(RenameFileCommand.class);

    /** The old path of the file we are persisting */
    private String oldFilePath;
    
    /** The new path of the file we are persisting */
    private String newFilePath;
    
    /** Constructor */
    public RenameFileCommand()
    {
        super();
    }
    
    /**
     * Initialises the command for execution
     * Retrieves required parameters from the execution context
     * 
     * @throws ResourceException Exception from Connector
     */
    private void initialise() throws ResourceException
    {
        oldFilePath = executionContext.getRequiredString(ExecutionContext.RENAMABLE_FILE_PATH_PARAM);
        newFilePath = executionContext.getRequiredString(ExecutionContext.NEW_FILE_PATH_PARAM);
    }

    /**
     * @see AbstractBaseFileTransferTransactionalResourceCommand#commit()
     */
    @Override
    protected void doCommit()
    {
        // Do Nothing
    }

    /** 
     * @see org.ikasan.connector.basefiletransfer.outbound.command.AbstractBaseFileTransferTransactionalResourceCommand#performExecute()
     */
    @Override
    protected ExecutionOutput performExecute() throws ResourceException
    {
        logger.info("execute called on command: [" + this + "]"); //$NON-NLS-1$ //$NON-NLS-2$
        initialise();
        
        renameFile(this.oldFilePath, this.newFilePath);
        return new ExecutionOutput();
    }

    /** 
     * @see AbstractBaseFileTransferTransactionalResourceCommand#rollback()
     */
    @Override
    protected void doRollback() throws ResourceException
    {
        logger.info("doRollback called on command: [" + this + "]"); //$NON-NLS-1$ //$NON-NLS-2$
        renameFile(this.newFilePath, this.oldFilePath);
    }
}
